BaseLocaleSyncLocalization class abstract interface

Implementers

Properties

delete → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
language_edit → String
no setter
language_new → String
no setter
one_more → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
no setter
no setter
splash_description → String
no setter
splash_title → String
no setter
string_edit → String
no setter
string_new → String
no setter
valid_string → String
no setter
welcome_title → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sasukeeeeee(int count) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited