In_Memory_LocaleSyncLocalization class

Implemented types

Constructors

In_Memory_LocaleSyncLocalization({required Map<String, dynamic> map, required String language})
const

Properties

delete → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
language → String
final
language_edit → String
no setteroverride
language_new → String
no setteroverride
map → Map<String, dynamic>
final
one_more → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
no setteroverride
no setteroverride
splash_description → String
no setteroverride
splash_title → String
no setteroverride
string_edit → String
no setteroverride
string_new → String
no setteroverride
valid_string → String
no setteroverride
welcome_title → String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sasukeeeeee(int count) → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited